SWDEV-360437 - fix tests with hipGetLastError() (#3040)

Unit_hipFreeImplicitSyncDev*
Unit_hipFreeImplicitSyncHost*
Unit_hipFreeImplicitSyncArray*
Unit_hipStreamCreateWithFlags_DefaultStreamInteraction
Unit_hipStreamSynchronize_NullStreamAndStreamPerThread

Change-Id: I382cf13bfe15bd8b1af657bdbb8c4f9043ea6f17
Este commit está contenido en:
ROCm CI Service Account
2022-11-01 06:08:26 +05:30
cometido por GitHub
padre d62eaeeda5
commit 41acbf98be
Se han modificado 2 ficheros con 2 adiciones y 3 borrados
-1
Ver fichero
@@ -397,7 +397,6 @@ static inline void runKernelForDuration(std::chrono::milliseconds duration,
static size_t ticksPerSecond = findTicksPerSecond();
const auto millis = duration.count();
hipLaunchKernelGGL(waitKernel, dim3(1), dim3(1), 0, stream, ticksPerSecond * millis / 1000);
HIP_CHECK(hipGetLastError());
}
} // namespace HipTest
+2 -2
Ver fichero
@@ -110,13 +110,13 @@ TEST_CASE("Unit_hipEventSynchronize_NoEventRecord_Positive") {
// Record the end_event
HIP_CHECK(hipEventRecord(end_event, NULL));
// End event has not been completed
HIP_CHECK_ERROR(hipEventQuery(end_event), hipErrorNotReady);
// When hipEventSynchronized is called on event that has not been recorded,
// the function returns immediately
HIP_CHECK(hipEventSynchronize(dummy_event));
// End event has not been completed
HIP_CHECK_ERROR(hipEventQuery(end_event), hipErrorNotReady);
// Wait for end_event to complete
HIP_CHECK(hipEventSynchronize(end_event));